import type { Context } from '@opentelemetry/api';
import type { Span } from '@opentelemetry/sdk-trace-base';
import type { SpanProcessor } from '@opentelemetry/sdk-trace-base';
export declare const TOKENS_HEADER = "x-agentuity-tokens";
export declare const DURATION_HEADER = "x-agentuity-duration";
export declare class TokenSpanProcessor implements SpanProcessor {
    onStart(_span: Span, _context: Context): void;
    onEnd(span: Span): void;
    forceFlush(): Promise<void>;
    shutdown(): Promise<void>;
}
//# sourceMappingURL=_tokens.d.ts.map