/**
 * An implementation of the EvalRunEventProvider which just logs locally
 */
export class LocalEvalRunEventProvider {
    /**
     * called when the eval run starts
     *
     * @param event EvalRunStartEvent
     */
    async start(event) {
        console.log('EvalRun started:', event);
    }
    /**
     * called when the eval run completes
     *
     * @param event EvalRunCompleteEvent
     */
    async complete(event) {
        console.log('EvalRun completed:', event);
    }
}
//# sourceMappingURL=local.js.map